<?php

class Mountee_lib
{

	public static $dum_file_id = 'mt-dum';

	public function __construct()
	{
		ee()->load->library('logger');
	}

	/**
	 * Check the license entered in Mountee
	 */
	public function check_license()
	{
		$mountee_license = Mountee_settings::get_setting('mountee_license');
		if ($mountee_license)
		{
			$cached_result = ee()->cache->get('Mountee_MLC_result');
			if ($cached_result)
			{
				$cached_content = unserialize($cached_result);
				// If we're still using the same license
				//   if not, we'll need to try and see if the new license is valid
				if ($cached_content['license'] == $mountee_license)
				{
					if ($cached_content['valid'] == 'y')
					{
						return TRUE;
					}
					else if ($cached_content['valid'] == 'n')
					{
						return FALSE;
					}
				}
			}

			$result = MLC_Api::check_license($mountee_license);
			if ($result === NULL)
			{
				ee()->logger->developer('Mountee: Issue when contacting MLC Api');
			}
			if ($result)
			{
				$cache_ttl = (60*60*24*30);
				$cached_result = 'y';
			}
			else
			{
				if ($result !== NULL)
				{
					ee()->logger->developer('Mountee: License not valid');
				}
				$cache_ttl = (60*60*24);
				$cached_result = 'n';
			}
			$cached_str = serialize(array('license' => $mountee_license, 'valid' => $cached_result));
			ee()->cache->save('Mountee_MLC_result', $cached_str, $cache_ttl);
			return $result;
		}
		return FALSE;
	}

	/**
	 * Converts a design object to an specific array, that'll be json encoded and sent back to Mountee app
	 * We handles snippets and golbal vars as 'standard' templates
	 * @param $object The EE object to convert to a specific structure for Mountee App
	 * @throw Exception if $object is not an object or is not a template, templategroup, snippet or variable
	 * @return array containing the specific structure
	 */
	public function convert_to_mountee_array($object)
	{
		if (is_object($object))
		{
			if (get_class($object) == 'EllisLab\ExpressionEngine\Model\Template\Template')
			{	
				return array(
					'id' 				=> (int)$object->template_id,
					'name' 				=> $object->template_name.'.'.Mountee_lib::get_extension_from_type($object->template_type),
					'type'				=> '',
					// 'last_modified'	=> (int)$object->edit_date,
					// 'should_cache'	=> (bool)($object->cache =='y'),
					// 'cache_refresh'		=> (int)$object->refresh,
					// 'allow_php'			=> (bool)($object->allow_php =='y'),
					// 'php_parse_output'	=> (bool)($object->php_parse_location =='o'),
					// 'hits'				=> (int)$object->hits,
					'data'				=> base64_encode($object->template_data),
					// 'save_template_file'=> FALSE
				);
			}
			else if (get_class($object) == 'EllisLab\ExpressionEngine\Model\Template\TemplateGroup')
			{
				// var_dump($object);
				// A template group is 'special' when it's the default one
				$template_group_arr = array(
					'id' 				=> (int)$object->group_id,
					'name'				=> $object->group_name,
					//'is_site_default'	=> (bool)($object->is_site_default == 'y'),
					'is_special'		=> (bool)($object->is_site_default == 'y'),
				);
				
				// If templates are present, we catch them too
				if ($object->Templates)
				{
					$templates_arr = array();
					foreach ($object->Templates as $template)
					{
						$templates_arr[] = $this->convert_to_mountee_array($template);
					}
					$template_group_arr['files'] = $templates_arr;
				}
				
				return $template_group_arr;
			}
			else if(get_class($object) == 'EllisLab\ExpressionEngine\Model\Template\Snippet')
			{
				return array(
					'id' 		=> (int)$object->snippet_id,
					'name' 		=> $object->snippet_name.'.php',
					'type'      => '',
					'data'		=> base64_encode($object->snippet_contents)
				);
			}
			else if(get_class($object) == 'EllisLab\ExpressionEngine\Model\Template\GlobalVariable')
			{
				return array(	
					'id' 		=> (int)$object->variable_id,
					'name' 		=> $object->variable_name.'.php',
					'type'      => '',
					'data'		=> base64_encode($object->variable_data)
				);
			}
			else
			{
				throw new Exception('Object '.get_class($object).' cannot be converted to Mountee array.');
			}
		}
		else
		{
			throw new Exception('Argument passed is no object.');
		}
	}

	/**
	 * Creates a structure like a template group, but for Snippets
	 * @param $snippets_collection The collection of all snippets
	 * @return array Structured specificaly for Mountee App
	 */
	public function create_snippets_object($snippets_collection)
	{
		// Manually create a folder structure for snippets
		$snippets_object = array('id' => 'snippets', 'name' => 'Snippets', 'is_special' => TRUE, 'files' => array());
		foreach ($snippets_collection as $snippet)
		{
			$snippets_object['files'][] = $this->convert_to_mountee_array($snippet);
		}
		return $snippets_object;
	}
	
	/**
	 * Creates a structure like a template group, but for Variables
	 * @param $variables_collection The collection of all variables
	 * @return array Structured specificaly for Mountee App
	 */
	public function create_variables_object($variables_collection)
	{
		// Manually create a folder structure for global vars
		$variables_obj = array('id' => 'variables', 'name' => 'Variables', 'is_special' => TRUE, 'files' => array());
		foreach ($variables_collection as $variable)
		{
			$variables_obj['files'][] = $this->convert_to_mountee_array($variable);
		}
		return $variables_obj;
	}

	/**
	 * Get the file extension for a specific template type
	 * @param $template_type  The EE Template type
	 */
	public static function get_extension_from_type($template_type)
	{
		switch ($template_type) {
			case 'webpage':
				return 'php';
				break;
			case 'feed':
				return 'rss';
				break;
			case 'css':
				return 'css';
				break;
			case 'js':
				return 'js';
				break;
			case 'static':
				return 'html';
				break;
			case 'xml':
				return 'xml';
				break;
			default:
				return 'php';
				break;
		}
	}

	/**
	 * Get the template type from a file extension
	 * @param $file_extension  The file extension
	 */
	public static function get_type_from_extension($file_extension)
	{
		switch ($file_extension) {
			case 'php':
				return 'webpage';
				break;
			case 'rss':
				return 'feed';
				break;
			case 'css':
				return 'css';
				break;
			case 'js':
				return 'js';
				break;
			case 'html':
				return 'static';
				break;
			case 'xml':
				return 'xml';
				break;
			default:
				return 'webpage';
				break;
		}
	}

	public static function get_license_dummy_file()
	{
		return array(
			'id'	=> Mountee_lib::$dum_file_id,
			'name'	=> 'AN-UNLICENSED-DEMO.txt',
			'type'	=> '',
			'data'	=> base64_encode(lang('mountee_dummy_license_file_content'))
		);
	}
}